==> loncapa-2.5.0.tar.gz: loncapa-2.5.0/loncom/auth/localauth.pm <==
# The LON-CAPA dummy localauthentication mechnism
#
# $Id: localauth.pm,v 1.5 2007/01/19 02:57:33 albertel Exp $
#
# Copyright Michigan State University Board of Trustees
#
# This file is part of the LearningOnline Network with CAPA (LON-CAPA).
#
# LON-CAPA is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# LON-CAPA is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with LON-CAPA; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# /home/httpd/html/adm/gpl.txt
#
# http://www.lon-capa.org/
#
# 8/24 Guy Albertelli


package localauth;

# The localauth routine receives
# - the typed in username
# - the typed in password
# - the optional information that was stored when the authentication 
#   mechanism was specified 
# - the domain that was typed in
# It is expected to return a 1 if the user is authenticated and a 0 otherwise
# it can optionally return a negative value for an error condition. This
# negative value will get logged along with the user that caused it
# ----START LOCAL CHANGES HERE ----- DON'T DELETE THIS LINE
sub localauth {
    my ($username,$password,$optional_argument,$domain) = @_;
    return 0;
}
# ----END LOCAL CHANGES HERE ----- DON'T DELETE THIS LINE

1;
__END__

==> loncapa-2.11.2.tar.gz: loncapa-2.11.2/loncom/auth/localauth.pm <==
# The LON-CAPA dummy localauthentication mechnism
#
# $Id: localauth.pm,v 1.7 2008/11/18 19:14:34 jms Exp $
#
# Copyright Michigan State University Board of Trustees
#
# This file is part of the LearningOnline Network with CAPA (LON-CAPA).
#
# LON-CAPA is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# LON-CAPA is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with LON-CAPA; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# /home/httpd/html/adm/gpl.txt
#
# http://www.lon-capa.org/
#
# 8/24 Guy Albertelli

=pod

=head1 NAME

Apache::localauth

=head1 SYNOPSIS

The localauth routine receives
 - the typed in username
 - the typed in password
 - the optional information that was stored when the authentication mechanism was specified 

=head1 OVERVIEW

It is expected to return a 1 if the user is authenticated and a 0 otherwise
it can optionally return a negative value for an error condition. This
negative value will get logged along with the user that caused it.

=cut


package localauth;


# ----START LOCAL CHANGES HERE ----- DON'T DELETE THIS LINE
sub localauth {
    my ($username,$password,$optional_argument,$domain) = @_;
    return 0;
}
# ----END LOCAL CHANGES HERE ----- DON'T DELETE THIS LINE

1;
__END__
